/*!
 *
 * Copyright 2024 Karlsruhe Institute of Technology.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
export class HSLColor {
    constructor(hue, sat, lum) {
        this.hue = hue;
        this.sat = sat;
        this.lum = lum;
    }
    static async generateColor(text) {
        if (window.crypto && window.crypto.subtle) {
            const hashBuffer = await window.crypto.subtle.digest('SHA-256', new TextEncoder().encode(text));
            const hashArray = Array.from(new Uint8Array(hashBuffer));
            const hashHex = hashArray.map(b => b.toString(16).padStart(2, '0')).join('');
            const hue = (parseInt(hashHex, 16) % 36000) / 100;
            const lum = (parseInt(hashHex, 16) % 450) / 10;
            const sat = (parseInt(hashHex, 16) % 250) / 10;
            return new HSLColor(hue, 50 + sat, 30 + lum);
        }
        else {
            const hexText = text
                .split('')
                .map(c => c.charCodeAt(0).toString(16))
                .join('');
            const hue = (parseInt(hexText, 36) % 36000) / 100;
            const lum = (parseInt(hexText, 36) % 450) / 10;
            const sat = (parseInt(hexText, 36) % 250) / 10;
            return new HSLColor(hue, 50 + sat, 30 + lum);
        }
    }
    toString() {
        return `hsl(${this.hue}, ${this.sat}%, ${this.lum}%)`;
    }
}
//# sourceMappingURL=HSLColor.js.map
