/*!
 *
 * Copyright 2024 Karlsruhe Institute of Technology.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
import { h } from "@stencil/core";
import { GenericIdentifierType } from "../utils/GenericIdentifierType";
export class DateType extends GenericIdentifierType {
    getSettingsKey() {
        return 'DateType';
    }
    hasCorrectFormat() {
        const regex = new RegExp('^([0-9]{4})-([0]?[1-9]|1[0-2])-([0-2][0-9]|3[0-1])(T([0-1][0-9]|2[0-3]):([0-5][0-9]):([0-5][0-9](.[0-9]*)?(Z|([+|-]([0-1][0-9]|2[0-3]):[0-5][0-9])){1}))$');
        return regex.test(this.value);
    }
    init() {
        this._date = new Date(this.value);
        return;
    }
    isResolvable() {
        return false;
    }
    renderPreview() {
        return h("span", null, this._date.toLocaleString());
    }
}
//# sourceMappingURL=DateType.js.map
