/*!
 *
 * Copyright 2024 Karlsruhe Institute of Technology.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
import { Parser } from "./Parser";
import { renderers } from "./utils";
export class FoldableItem {
    constructor(priority, keyTitle, value, keyTooltip, keyLink, valueRegex, renderDynamically) {
        this._estimatedTypePriority = 0;
        this._priority = priority;
        this._keyTitle = keyTitle;
        this._value = value;
        this._keyTooltip = keyTooltip;
        this._keyLink = keyLink;
        this._valueRegex = valueRegex;
        this._renderDynamically = renderDynamically;
        if (renderDynamically)
            this._estimatedTypePriority = renderers.length;
        else
            this._estimatedTypePriority = Parser.getEstimatedPriority(this._value);
    }
    get priority() {
        return this._priority;
    }
    get keyTitle() {
        return this._keyTitle;
    }
    get value() {
        return this._value;
    }
    get keyTooltip() {
        return this._keyTooltip;
    }
    get keyLink() {
        return this._keyLink;
    }
    get valueRegex() {
        return this._valueRegex;
    }
    get renderDynamically() {
        return this._renderDynamically;
    }
    get estimatedTypePriority() {
        return this._estimatedTypePriority;
    }
    isValidValue() {
        return this._valueRegex.test(this._value);
    }
}
//# sourceMappingURL=FoldableItem.js.map
