/*!
 * 
 * Copyright 2024 Karlsruhe Institute of Technology.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *       http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 */
import { r as registerInstance, h, H as Host } from './index-39b8e937.js';

const LocaleVisualization = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.showFlag = true;
    }
    render() {
        const getLocaleDetail = (locale) => {
            const userLocale = [navigator.language.split('-')[0]];
            const type = locale.split('-').length > 1 ? 'language' : 'region';
            const friendlyName = new Intl.DisplayNames(userLocale, { type: type }).of(locale.toUpperCase());
            if (friendlyName == locale.toUpperCase()) {
                return new Intl.DisplayNames(userLocale, { type: 'language' }).of(locale.toUpperCase());
            }
            if (type === 'language') {
                const flag = generateFlag(locale.split('-')[1]);
                return `${flag}${friendlyName}`;
            }
            return `${generateFlag(locale)}${friendlyName}`;
        };
        const generateFlag = (locale) => {
            if (this.showFlag === false)
                return '';
            const codePoints = locale
                .toUpperCase()
                .split('')
                .map(char => 127397 + char.charCodeAt(0));
            return String.fromCodePoint(...codePoints) + ' ';
        };
        return (h(Host, null, h("span", null, getLocaleDetail(this.locale))));
    }
};

export { LocaleVisualization as locale_visualization };

//# sourceMappingURL=locale-visualization.entry.js.map